/*
 * Copyright 2005, 2006 University of Leiden.
 *
 * This file is part of MIA+EWS.
 *
 * MIA+EWS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MIA+EWS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MIA; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/*******************************************************************************
* E.S.O. - VLT project
*
* "@(#) $Id: dispersion.h,v 1.1 2003/07/29 20:16:44 jaffe Exp $"
*
* who       when      what
* --------  --------  ----------------------------------------------
* jaffe 2003-07-24  written
*/

/************************************************************************
 *
 *----------------------------------------------------------------------
 */
/* $Id: dispersion.h,v 1.1 2003/07/29 20:16:44 jaffe Exp $ */

#ifndef _DISPERSION_TABLE_H
#define _DISPERSION_TABLE_H
/*----------------------------------------------------------------------- */
/* Dispersion table FITS binary tables routines                                */
/*----------------------------------------------------------------------- */
#include "VLTItable.h"

typedef struct      /* table definition for dispersion table */
{
  table_def *def;       /* basic table information */
  long   row;           /* last row (0-rel) read or written, -1=> none. */
  char   *date_obs;     /* observing date */
  char   *disp_type;    /* solution type*/
  int    time_col;      /* Time column number (0-rel) */
  int    telescope_col; /* Telescope number column number (0-rel) */
  int    dispersion_col;     /* dispersion column number */
} dispersion_table_def;

typedef struct      /* structure used for jaffe row */
{
  double     time;     /* time (days) */
  int        telescope; /* which telescope */
  float      dispersion;/* dispersion (degrees) */
  table_row *raw;    /* generic table row */
} dispersion_table_row;

/* public functions */

/* dispersion_table_row functions */
dispersion_table_row* make_dispersion_table_row(dispersion_table_def* table);
/*----------------------------------------------------------------------- */
/*   Make an dispersion_table_row structure                           */
/*   Inputs:                                                              */
/*      table     pointer to dispersion_table table structure         */
/*   Returns:                                                             */
/*      An dispersion_table_row structure pointer ; NULL => failure   */
/*      Data pointers set to generic structure values                     */
/*----------------------------------------------------------------------- */

void kill_dispersion_table_row (dispersion_table_row *row);
/*----------------------------------------------------------------------- */
/*   Delete an dispersion_table_row structure                         */
/*   Inputs:                                                              */
/*      row    pointer to the dispersion_table_row structure.         */
/*----------------------------------------------------------------------- */

/* dispersion_table functions */

dispersion_table_def* 
make_dispersion_table_def(fitsfile *fptr, char *date_obs, 
   char *dispType, int *ierr);
/*----------------------------------------------------------------------- */
/*   Make a new dispersion_table in an open FITS file                 */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*      date_obs  Date (yyyy-mm-dd) observations began                    */
/*      dispType  type of dispersion solution                             */
/*   Output:                                                              */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      A dispersion_table_def pointer; NULL indicates failure        */
/*----------------------------------------------------------------------- */

dispersion_table_def* 
open_dispersion_table(fitsfile *fptr, int *ierr);
/*----------------------------------------------------------------------- */
/*   Open an existing dispersion_table in the active FITS file        */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*   Output:                                                              */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      An dispersion_table_def pointer; NULL indicates failure       */
/*----------------------------------------------------------------------- */

int read_dispersion_table(fitsfile *fptr,  dispersion_table_def* table, 
			    dispersion_table_row *row, long row_number,
			    int *ierr);
/*----------------------------------------------------------------------- */
/*   Read the next row from an dispersion_table                       */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*      table     table definitions structure from open or create         */
/*      row_number which row (1-rel) in the table                         */   
/*                 -1 => next row                                         */  
/*   Input/output:                                                        */
/*      row       pointer to an extant row structure                      */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

int write_dispersion_table(fitsfile *fptr, dispersion_table_def *table, 
			     dispersion_table_row *row,  long row_number,
			     int *ierr);
/*----------------------------------------------------------------------- */
/*   Write  the next row to an dispersion_table                               */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*      table     table definitions structure from open or create         */
/*      row       pointer to an extant row structure                      */
/*      row_number which row (1-rel) in the table                         */
/*                 -1 => next row                                         */  
/*   Input/output:                                                        */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

int close_dispersion_table(fitsfile *fptr, dispersion_table_def* table, 
			     int *ierr);
/*----------------------------------------------------------------------- */
/*   Close an open dispersion_table, associated structures are        */
/*   destroyed                                                            */
/*   Note: this closes the full FITS file                                 */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

void kill_dispersion_table_def (dispersion_table_def* table);
/*----------------------------------------------------------------------- */
/*   Delete an dispersion_table structure                             */
/*   Inputs:                                                              */
/*      table     table definitions structure from open or create         */
/*----------------------------------------------------------------------- */

#endif /* end _DISPERSION_TABLE_H */
/* */
